@@ -8,7 +8,7 @@ This module provides LDAP core operations.
 from collections import OrderedDict as _OrderedDict
 
 from _libldap import _LDAPError, _LDAPObject, _LDAPObjectControl
-from .constants import LDAP_CONTROL_PAGEDRESULTS
+from .constants import LDAP_CONTROL_PAGEDRESULTS, LDAP_OPT_REFERRALS
 from .exceptions import _generate_exception
 
 __all__ = (
@@ -56,21 +56,26 @@ class LDAP(_LDAPObject):
     :param options:
         LDAP options. If this is set, set_option() method is called.
         (the default is [], which implies no options are set)
+    :param start_tls:
+        Flag for start_tls() will be executed or not
+        (the default is False, which implies start_tls() is not done)
 
     :type uri:
         str, list or tuple
     :type bind_user:
-        str
+        str or None
     :type bind_password:
-        str
+        str or None
     :type options:
         [(option, value, is_global)]
+    :type start_tls:
+        bool
 
     :raises:
         LDAPError
     """
 
-    def __init__(self, uri, bind_user=None, bind_password=None, options=[]):
+    def __init__(self, uri, bind_user=None, bind_password=None, options=[], start_tls=False):
         self.bind_user = 'anonymous'
         self.__bind_password = None
         if bind_user and bind_password:
@@ -83,12 +88,16 @@ class LDAP(_LDAPObject):
                 super().__init__(uri)
         except _LDAPError as e:
             raise _generate_exception(e) from None
+        # NOTE: We set LDAP_OPT_REFERRALS False by default. This is same behavior
+        #       with OpenLDAP client tool. You can overwrite by using options parameter.
+        self.set_option(LDAP_OPT_REFERRALS, False)
         try:
             for option, value, is_global in options:
                 self.set_option(option, value, is_global)
         except ValueError:
             raise ValueError("Invalid parameter: 'options' parameter type is [(option, value, is_global)]") from None
-
+        if start_tls:
+            self.start_tls()
 
     def __enter__(self):
         if self.bind_user and self.__bind_password:
@@ -967,10 +976,7 @@ class LDAP(_LDAPObject):
         :raises:
             LDAPError
         """
-        if 'ordered_attributes' in kwargs:
-            ordered_attributes = kwargs.pop('ordered_attributes')
-        else:
-            ordered_attributes = False
+        ordered_attributes = kwargs.pop('ordered_attributes', False)
         results = self.result(*args, **kwargs)
         if results:
             if results[-1]['return_code'] != LDAP_SUCCESS:
